==> print-manager_17.12.3.orig.tar.xz: print-manager-17.12.3/libkcups/ProcessRunner.h <==
/***************************************************************************
 *   Copyright (C) 2015 Jan Grulich                                        *
 *   <jgrulich@redhat.com>                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef PROCESS_RUNNER_H
#define PROCESS_RUNNER_H

#include <QObject>

class Q_DECL_EXPORT ProcessRunner : public QObject
{
    Q_OBJECT
public:
    explicit ProcessRunner(QObject *parent = 0);

public Q_SLOTS:
    void configurePrinter(const QString &printerName);
    void openPrintQueue(const QString &printerName);
    void openPrintKCM();
};

#endif // PROCESS_RUNNER_H

==> print-manager-19.08.1.tar.xz: print-manager-19.08.1/libkcups/ProcessRunner.h <==
/***************************************************************************
 *   Copyright (C) 2015 Jan Grulich                                        *
 *   <jgrulich@redhat.com>                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; see the file COPYING. If not, write to       *
 *   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,  *
 *   Boston, MA 02110-1301, USA.                                           *
 ***************************************************************************/

#ifndef PROCESS_RUNNER_H
#define PROCESS_RUNNER_H

#include <QObject>

class Q_DECL_EXPORT ProcessRunner : public QObject
{
    Q_OBJECT
public:
    explicit ProcessRunner(QObject *parent = nullptr);

public Q_SLOTS:
    void configurePrinter(const QString &printerName);
    void openPrintQueue(const QString &printerName);
    void openPrintKCM();
};

#endif // PROCESS_RUNNER_H
